==> newsstar-1.2.2.tar.gz: newsstar-1.2.2/src/groupcount.h <==
#ifndef GROUPCOUNT_H
#define GROUPCOUNT_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Keep track of how many articles are to be downloaded for each group across
 * all servers */

/* $Id: groupcount.h,v 1.1 2004/08/21 18:36:13 realh Exp $ */

#ifndef DEFNS_H
#include "defns.h"
#endif

typedef struct GroupCountData GroupCountData;

/* Adds a new group to the pool or increases its server count if it already
 * exists */
GroupCountData *groupcount_add_group(const char *name);

/* Increase article count for named group */
void groupcount_inc_articles(GroupCountData *);

/* When all articles have been added for a server, decrease count of servers
 * outstanding; when it reaches 0 return grand total of all articles added,
 * otherwise -1 */
int groupcount_server_done_get_total(GroupCountData *);

#endif /* ! GROUPCOUNT_H */

==> newsstar-1.5.3.tar.gz: newsstar-1.5.3/src/groupcount.h <==
#ifndef GROUPCOUNT_H
#define GROUPCOUNT_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Keep track of how many articles are to be downloaded for each group across
 * all servers */


#ifndef DEFNS_H
#include "defns.h"
#endif

typedef struct GroupCountData GroupCountData;

/* Adds a new group to the pool or increases its server count if it already
 * exists */
GroupCountData *groupcount_add_group(const char *name);

/* Increase article count for named group */
void groupcount_inc_articles(GroupCountData *);

/* When all articles have been added for a server, decrease count of servers
 * outstanding; when it reaches 0 prints grand total of all articles added,
 * using deblog_brief. */
void groupcount_server_done(GroupCountData *);

#endif /* ! GROUPCOUNT_H */
